//----------------------------------------------------------------------------
//----------------------------------------------------------------------------

#include "ros/ros.h"
#include "std_msgs/String.h"
#include <tf/transform_broadcaster.h>
#include <nav_msgs/Odometry.h>

//----------------------------------------------------------------------------

//using namespace std;

tf::TransformBroadcaster *odom_broadcaster;

//----------------------------------------------------------------------------

void odomCallback(const nav_msgs::Odometry::ConstPtr& odom)
{
  double x, y, z;
  double ax, ay, az, aw;

  ax = odom->pose.pose.orientation.x;
  ay = odom->pose.pose.orientation.y;
  az = odom->pose.pose.orientation.z;
  aw = odom->pose.pose.orientation.w;

  x = odom->pose.pose.position.x;
  y = odom->pose.pose.position.y;
  z = odom->pose.pose.position.z;

  //  printf("got GT odom position %.3lf %.3lf %.3lf, orientation %.3lf %.3lf %.3lf %.3lf\n", x, y, z, ax, ay, az, aw); fflush(stdout);

  odom_broadcaster->sendTransform(tf::StampedTransform(tf::Transform(tf::Quaternion(ax, ay, az, aw), tf::Vector3(x, y, z)),
						       odom->header.stamp, "odom", "base_footprint"));

}

//----------------------------------------------------------------------------

int main(int argc, char **argv)
{
  ros::init(argc, argv, "robot_pose_ground_truth");

  ros::NodeHandle n;

  ros::Subscriber sub = n.subscribe("base_pose_ground_truth", 1000, odomCallback);

  odom_broadcaster = new tf::TransformBroadcaster();

  ros::Rate loop_rate(60);

  while (ros::ok()) {


    ros::spinOnce();

    loop_rate.sleep();

  }

  return 0;
}

//----------------------------------------------------------------------------
//----------------------------------------------------------------------------
